# pyfsr

Goal of the library is be a Python Client for the FortiSOAR Rest API. 

## Installation

```bash
pip install pyfsr
```

This library is a work in progress and is not yet ready for production use.

